#declare S1 = seed (66);

global_settings {
    radiosity {
        count 500
        pretrace_start 1
        pretrace_end 0.0025
        media on
    }
}

camera {
    location -6*z
    up y
    right 4/3*x
    look_at 0.775*y
    angle 55
}

light_source {<-10, 10, -20>  color rgb 1}
light_source {0  color rgb <1, 1, 0.2>*0.175  shadowless}

#declare moon_obj =
    sphere {
        0, 1
        pigment {
            image_map {
                sys "moon 01.bmp"
                interpolate 2
            }
            translate -0.509
            scale 2.22*<47/40, 1, 1>
        }
        finish {ambient 0  diffuse 0.875}
        normal {
            bump_map {
                sys "moon 01.bmp"
                interpolate 2
            } 0.8
            translate -0.509
            scale 2.22*<47/40, 1, 1>
        }
        double_illuminate
    }

#declare flame_rad = 1;
#declare flame_diam = 0.2;
#declare flame_power = 1.07;
#declare flame_curl_size = 2.75;
#declare flame_curl_strength = 0.15;
#declare flame_curl_ratio = 1.85;
#declare flame_curl_start = -6.5*flame_diam;
#declare halo_rad = 1;
#declare halo_diam = 0.15;
#declare halo_brightness = 0.475;
#declare stars_brightness = 0.375;
#declare air_color = color rgb <0.92, 0.96, 1>;

#declare flame_func_0 =
    function {
        select (
            sqrt (x*x+y*y+z*z)-flame_rad,
            -exp (1/(sqrt (x*x+y*y+z*z)-flame_rad-0.02)*flame_diam),
            -exp (-1/(sqrt (x*x+y*y+z*z)-flame_rad+0.02)*flame_diam)
        )
    }

#declare flame_func_1 =
    function {flame_func_0 (x, select (y, y, atan (y*flame_power)/flame_power), z)}

#declare flame_curl_func = array [3]

#declare I = 3;
#while (I > 0)
    #declare flame_curl_func [I-1] =
        function {
            pigment {
                agate
                translate <rand (S1), rand (S1), rand (S1)>*216.2
                scale flame_curl_size*<1/flame_curl_ratio, 1, 1/flame_curl_ratio>
                color_map {
                    [0  color rgb -flame_curl_strength]
                    [1  color rgb flame_curl_strength]
                }
            }
        }
    #declare I = I-1;
#end

#declare flame_func =
    function {
        flame_func_1 (
            x+flame_curl_func [0] (x, y, z).gray*(y+flame_rad-flame_curl_start),
            y+flame_curl_func [1] (x, y, z).gray*(y+flame_rad-flame_curl_start*0.25),
            z+flame_curl_func [2] (x, y, z).gray*(y+flame_rad-flame_curl_start)
        )
    }

#declare flame_obj_rad = 10;

#declare flame_and_halo_obj =
    sphere {
        0, flame_obj_rad
        hollow
        pigment {color rgbt 1}
        interior {
            media {
                method 2
                samples 120, 120
                intervals 10
                emission 0.1
                density {
                    function {flame_func (x, y, z)}
                    color_map {
                        [0     color rgb 0]
                        [0.1   color rgb 0]
                        [0.75  color rgb <1, 0.5, 0>*1.35*1.5]
                        [1     color rgb <1, 1, 0.2>*11*1.5]
                    }
                }
                density {
                    function {sqrt (x*x+y*y+z*z)/flame_obj_rad}
                    color_map {
                        [0  color rgb 1]
                        [1  color rgb 0]
                    }
                }
            }
            media {
                method 2
                samples 80, 80
                intervals 10
                emission 0.1
                density {
                    function {flame_func (x, y, z)}
                    color_map {
                        [0      color rgb 0]
                        [0.625  color rgb 0]
                        [0.7    color rgb <0, 0.1, 1>*1.53*1.5]
                        [0.775  color rgb 0]
                        [1      color rgb 0]
                    }
                }
                density {
                    function {sqrt (x*x+y*y+z*z)/flame_obj_rad}
                    color_map {
                        [0  color rgb 1]
                        [1  color rgb 0]
                    }
                }
            }
            media {
                method 3
                samples 50, 50
                intervals 3
                emission 0.2
                density {
                    function {
                        select (
                            z,
                            select (
                                sqrt (x*x+y*y+z*z)-halo_rad,
                                -exp (1/(sqrt (x*x+y*y+z*z)-halo_rad-0.02)*flame_diam),
                                -exp (-1/(sqrt (x*x+y*y+z*z)-halo_rad+0.02)*flame_diam)
                            ),
                            0
                        )
                    }
                    color_map {
                        [0  color rgb 0]
                        [1  color rgb halo_brightness*air_color]
                    }
                }
            }
        }
    }


object {moon_obj}
object {flame_and_halo_obj}

sky_sphere {
    pigment {
        granite
        scale 0.0205
        color_map {
            [0    color rgb 0]
            [0.9  color rgb 0]
            [0.9  color rgb stars_brightness]
            [1    color rgb stars_brightness]
        }
    }
}

fog {
    fog_type 2
    distance 100
    fog_alt 0.75
    fog_offset 0.35
    up <0, 1, 0.365>
    color rgb air_color*0.23
}